package app22;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Scanner;

import javax.swing.JOptionPane;

public class SQLTool {
    private String dbDriverClass;
    private String dbUrl;
    private String dbUserName;
    private String dbPassword;
    private static final int COLUMN_WIDTH = 25;

    public SQLTool(String dbDriverClass, String dbUrl, String dbUserName,
            String dbPassword) {
        this.dbDriverClass = dbDriverClass;
        this.dbUrl = dbUrl;
        this.dbUserName = dbUserName;
        this.dbPassword = dbPassword;
    }

    public void executeSQL(String sql) {
        if (sql == null) {
            return;
        }
        sql = sql.trim();
        Connection connection = null;
        Statement statement = null;
        ResultSet resultSet = null;
        try {
            Class.forName(dbDriverClass);
            connection = DriverManager.getConnection(dbUrl,
                    dbUserName, dbPassword);
            statement = connection.createStatement();
            if (sql.toUpperCase().startsWith("SELECT")) {
                resultSet = statement.executeQuery(sql);
                ResultSetMetaData metaData = resultSet.getMetaData();
                int columnCount = metaData.getColumnCount();
                for (int i = 0; i < columnCount; i++) {
                    System.out.print(pad(metaData.getColumnName(i + 1)));
                }
                // draw line
                int length = columnCount * COLUMN_WIDTH;
                StringBuilder sb = new StringBuilder(length);
                for (int i = 0; i < length; i++) {
                    sb.append('=');
                }
                System.out.println();
                System.out.println(sb.toString());

                while (resultSet.next()) {
                    String[] row = new String[columnCount];
                    for (int i = 0; i < columnCount; i++) {
                        row[i] = resultSet.getString(i + 1);
                        System.out.print(pad(row[i]));
                    }
                    System.out.println();
                }
                resultSet.close();

            } else {
                int recordsUpdated = statement.executeUpdate(sql);
                System.out.println(recordsUpdated + " record(s) updated");
            }
            statement.close();
            connection.close();
        } catch (ClassNotFoundException e1) {
            System.out.println(e1.toString());
        } catch (SQLException e2) {
            System.out.println(e2.toString());
        } catch (Exception e3) {
            System.out.println(e3.toString());
        } finally {
            if (resultSet != null) {
                try {
                    resultSet.close();
                } catch (Exception e) {
                }
            }
            if (statement != null) {
                try {
                    statement.close();
                } catch (Exception e) {
                }
            }
            if (connection != null) {
                try {
                    connection.close();
                } catch (Exception e) {
                }
            }

        }
    }

    // appends s with spaces so that the length is 25
    private String pad(String s) {
        int padCount = COLUMN_WIDTH - s.length();
        StringBuilder sb = new StringBuilder(25);
        sb.append(s);
        for (int i = 0; i < padCount; i++) {
            sb.append(" ");
        }
        return sb.toString();
    }

    public static void main(String[] args) {
        String dbDriverClass = "com.mysql.jdbc.Driver";
        String dbUrl = "jdbc:mysql://localhost:3306/test";
        String dbUserName = "root";
        String dbPassword = "";
        SQLTool sqlTool = new SQLTool(dbDriverClass, dbUrl, dbUserName,
                dbPassword);
        Scanner scanner = new Scanner(System.in);
        String sql = JOptionPane
                .showInputDialog(null, "Enter an SQL Statement");
        sqlTool.executeSQL(sql);
    }
}
